@@ -26,6 +26,7 @@ class AuthScope(Enum):
     :var CHANNEL_READ_HYPE_TRAIN:
     :var CHANNEL_MANAGE_BROADCAST:
     :var CHANNEL_READ_REDEMPTIONS:
+    :var CHANNEL_MANAGE_REDEMPTIONS:
     :var CLIPS_EDIT:
     :var USER_EDIT:
     :var USER_EDIT_BROADCAST:
@@ -49,6 +50,7 @@ class AuthScope(Enum):
     CHANNEL_READ_HYPE_TRAIN = 'channel:read:hype_train'
     CHANNEL_MANAGE_BROADCAST = 'channel:manage:broadcast'
     CHANNEL_READ_REDEMPTIONS = 'channel:read:redemptions'
+    CHANNEL_MANAGE_REDEMPTIONS = 'channel:manage:redemptions'
     CLIPS_EDIT = 'clips:edit'
     USER_EDIT = 'user:edit'
     USER_EDIT_BROADCAST = 'user:edit:broadcast'
@@ -188,11 +190,41 @@ class PubSubResponseError(Enum):
     UNKNOWN = 'unknown error'
 
 
+class CustomRewardRedemptionStatus(Enum):
+    """
+    :var UNFULFILLED:
+    :var FULFILLED:
+    :var CANCELED:
+    """
+    UNFULFILLED = 'UNFULFILLED'
+    FULFILLED = 'FULFILLED'
+    CANCELED = 'CANCELED'
+
+
+class SortOrder(Enum):
+    """
+    :var OLDEST:
+    :var NEWEST:
+    """
+    OLDEST = 'OLDEST'
+    NEWEST = 'NEWEST'
+
+
 class TwitchAPIException(Exception):
     """Base Twitch API Exception"""
     pass
 
 
+class InvalidRefreshTokenException(TwitchAPIException):
+    """used User Refresh Token is invalid"""
+    pass
+
+
+class NotFoundException(TwitchAPIException):
+    """Resource was not found with the given parameter"""
+    pass
+
+
 class TwitchAuthorizationException(TwitchAPIException):
     """Exception in the Twitch Authorization"""
     pass
